==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/fi.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "Generate backup codes" : "Luo varakoodit",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Varakoodit on luotu. {{used}}/{{total}} koodia on käytetty.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Nämä ovat varakoodisi. Tallenna ja/tai tulosta ne, koska et voi lukea koodeja myöhemmin",
    "Save backup codes" : "Tallenna varakoodit",
    "Print backup codes" : "Tulosta varakoodit",
    "Regenerate backup codes" : "Uudelleenluo varakoodit",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Jos uudelleenluot varakoodit, vanhat varakoodit poistetaan käytöstä.",
    "An error occurred while generating your backup codes" : "Tapahtui virhe varakoodeja luotaessa",
    "Nextcloud backup codes" : "Nextcloud-varakoodit",
    "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
    "You successfully logged in using two-factor authentication (%1$s)" : "Kirjauduit onnistuneesti sisään kaksivaiheista tunnistautumista käyttäen (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Kirjautumisyritys kaksivaiheista tunnistautumista käyttäen epäonnistui (%1$s)",
    "You created two-factor backup codes for your account" : "Loit kaksivaiheisen tunnistautumisen varakoodit tilillesi",
    "Backup code" : "Varakoodi",
    "Use backup code" : "Käytä varakoodia",
    "Second-factor backup codes" : "Kaksivaiheisen tunnistautumisen varakoodit"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/fi.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Tapahtui virhe varakoodeja luotaessa",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Nämä ovat varakoodisi. Tallenna ja/tai tulosta ne, koska et voi lukea koodeja myöhemmin",
    "Save backup codes" : "Tallenna varakoodit",
    "Print backup codes" : "Tulosta varakoodit",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Varakoodit on luotu. {used}/{total} koodia on käytetty.",
    "Regenerate backup codes" : "Uudelleenluo varakoodit",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Jos uudelleenluot varakoodit, vanhat varakoodit poistetaan käytöstä.",
    "Generate backup codes" : "Luo varakoodit",
    "You created two-factor backup codes for your account" : "Loit kaksivaiheisen tunnistautumisen varakoodit tilillesi",
    "Second-factor backup codes" : "Kaksivaiheisen tunnistautumisen varakoodit",
    "Backup code" : "Varakoodi",
    "Use backup code" : "Käytä varakoodia",
    "Two factor backup codes" : "Kaksivaiheiden tunnistautumisen varakoodit",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Varakoodit on luotu. {{used}}/{{total}} koodia on käytetty.",
    "Nextcloud backup codes" : "Nextcloud-varakoodit",
    "activated" : "aktivoitu",
    "updated" : "päivitetty",
    "created" : "luotu",
    "destroyed" : "tuhottu"
},
"nplurals=2; plural=(n != 1);");
